# django_site

A reusable Django app to generate a dynamic and responsive movie website template.

## Installation

```bash
pip install django_site_fer

django_site_fer generate myproject
cd myproject
python manage.py runserver
